pub struct KeyboardBackend<I: Index<usize, Output = R> = [Ref; 1], R = Ref, Ctx = Context, Ev: Debug = Event, PKS = PendingKeyState, KS = KeyState, S = System> { /* private fields */ }Expand description
The keyboard “backend”, manages the keyboard from the events received (presses/releases of coordinates on a keyboard layout). through to listing HID scancodes to report using HIDs.
Type parameters match Keymap.
Implementations
Sourceimpl<I, R, Ctx, Ev, PKS, KS, S> KeyboardBackend<I, R, Ctx, Ev, PKS, KS, S>
impl<I, R, Ctx, Ev, PKS, KS, S> KeyboardBackend<I, R, Ctx, Ev, PKS, KS, S>
Sourcepub fn new_with_keymap(keymap: Keymap<I, R, Ctx, Ev, PKS, KS, S>) -> Self
pub fn new_with_keymap(keymap: Keymap<I, R, Ctx, Ev, PKS, KS, S>) -> Self
Constructs a new keyboard backend with the given keymap.
Sourceimpl<I, R, Ctx, Ev, PKS, KS, S> KeyboardBackend<I, R, Ctx, Ev, PKS, KS, S>
impl<I, R, Ctx, Ev, PKS, KS, S> KeyboardBackend<I, R, Ctx, Ev, PKS, KS, S>
Sourcepub fn set_callbacks(&mut self, callbacks: KeymapCallbacks)
pub fn set_callbacks(&mut self, callbacks: KeymapCallbacks)
Set the keymap callbacks.
Sourcepub fn tick(&mut self) -> bool
pub fn tick(&mut self) -> bool
A time event.
This method must be called regularly, typically every millisecond.
Returns true if the pressed_key_codes have changed.
Sourcepub fn keymap_output(&self) -> &KeymapOutput
pub fn keymap_output(&self) -> &KeymapOutput
Returns the current keymap output.